"""
Module realizes metaclass for plugins
"""
import inspect
from abc import ABCMeta
from typing import List, Type


class PluginMeta(ABCMeta):
    """
    Metaclass for plugins storing.
    """

    registryPlugins: List[Type["BasePlugin"]] = []  #: list of available plugin classes

    def __new__(mcs, name, bases, attrs):  # pylint: disable-msg=C0204,W0221
        """
        Metaclass new method

        Args:
            name: class name
            bases: bases classes
            attrs: class attributes

        Returns:
            new class

        """
        obj = super().__new__(mcs, name, bases, attrs)

        # skip abstract plugins
        if inspect.isabstract(obj):
            return obj

        mcs.registryPlugins.append(obj)
        return obj
