"""
Module with utils for plugins.
"""

from typing import Union

from .base_struct import AttributeMatchResult, EventMatchResult, FaceMatchResult, MatchResult


def mergeResults(
    matchResults: list[MatchResult], limit: int
) -> Union[list[FaceMatchResult], list[EventMatchResult], list[AttributeMatchResult]]:
    """
    Merge sorted match results by similarity.

    Args:
        matchResults: match results
        limit: limit of results

    Returns:
        list of merged results
    """
    # assumes every result is not an error
    indexes = [0] * len(matchResults)
    result = [None] * limit
    resultIdx = 0

    while resultIdx < limit:
        maxMatchResultIdx = None
        maxScore = 0.0
        for i, r in enumerate(matchResults):
            if indexes[i] >= len(r.results):
                continue

            score = r.results[indexes[i]].similarity
            if score >= maxScore:
                maxScore = score
                maxMatchResultIdx = i

        if maxMatchResultIdx is None:
            # we've reached the end
            break

        result[resultIdx] = matchResults[maxMatchResultIdx].results[indexes[maxMatchResultIdx]]
        indexes[maxMatchResultIdx] += 1
        resultIdx += 1

    return list(filter(None, result))
