from typing import Tuple
from urllib.parse import urlparse


def parseConfiguratorAddress(configuratorAddress: str) -> Tuple[str, int]:
    """
    Get configurator address from command line arguments.

    Args:
        configuratorAddress: configurator address

    Returns:
        tuple<origin, apiVersion>
    """
    # < scheme >: // < netloc > / < path >; < params >? < query >  # <fragment>
    scheme, netloc, path, *_ = urlparse(configuratorAddress)

    if not netloc:
        # when only ip provided
        netloc, path = path, ""
    scheme = scheme or "http"
    host, port = netloc.split(":") if ":" in netloc else (netloc, 5070)

    configuratorApiVersion = int(path.split("/")[1]) if path else 1
    configuratorOrigin = f"{scheme}://{host}:{port}"
    return configuratorOrigin, configuratorApiVersion
